@@ -14,5 +14,6 @@ from .commands import gfile
 from .commands import gfolder
 from .commands import slack
 from .commands import asyncdown
+from . import utils
 
-__all__ = ["__version__", "main", "gfile", "gfolder", "slack", "asyncdown"]
+__all__ = ["__version__", "main", "gfile", "gfolder", "slack", "asyncdown", "utils"]
